LPSOLVER: LPSOLVER Function to call specified solver to sparse LP...

View source: R/qDEA.R

LPSOLVERR Documentation

LPSOLVER Function to call specified solver to sparse LP problem

Description

LPSOLVER Function to call specified solver to sparse LP problem

Usage

LPSOLVER(LP, solver = "highs")

Arguments

LP

An LP object

solver

LP solver Default='highs' Note: Versions for 'clp','highs','glpk' or 'rglpk' are available from author

Value

A list containing following components:

status = status of solver

objval = objective value

solution = lp primal solution

dual = lp dual solution

rcost = lp reduced cost

lhs = lp lhs associated with primal solution

TIME = total seconds to execute LP_* function

SMtime = seconds to transform form of sparse LP (if needed)

proctime = seconds required by specified solver to solve LP

LP = LP object


qDEA documentation built on April 13, 2026, 5:07 p.m.