Write.LP: Write.LP

View source: R/qDEA.R

Write.LPR Documentation

Write.LP

Description

Write a linear programming model to a csv file.

Usage

Write.LP(LP, path = NULL, filename = "LP.csv")

Arguments

LP

A linear programming object.

path

Directory to write LP .csv file to. REQUIRED to use function

filename

Character string specifying the csv file name.

Details

This function converts a linear programming model to a dense representation and writes it to a csv file that can be opened or solved using spreadsheet based solvers.

Value

A csv file written to disk.


qDEA documentation built on April 13, 2026, 5:07 p.m.