| Write.LP | R Documentation |
Write a linear programming model to a csv file.
Write.LP(LP, path = NULL, filename = "LP.csv")
LP |
A linear programming object. |
path |
Directory to write LP .csv file to. REQUIRED to use function |
filename |
Character string specifying the csv file name. |
This function converts a linear programming model to a dense representation and writes it to a csv file that can be opened or solved using spreadsheet based solvers.
A csv file written to disk.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.